==> trimica-1.4.2%2B1.21.8-fabric-sources.jar: com/bawnorton/trimica/client/mixin/render/ShieldSpecialRendererMixin.java <==
package com.bawnorton.trimica.client.mixin.render;

import com.bawnorton.trimica.api.client.TrimicaClientApi;
import dev.kikugie.fletching_table.annotation.MixinEnvironment;
import net.minecraft.class_10509;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_600;
import net.minecraft.class_811;
import net.minecraft.class_9323;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

//? if >=1.21.10
/*import net.minecraft.client.renderer.SubmitNodeCollector;*/

@MixinEnvironment("client")
@Mixin(class_10509.class)
abstract class ShieldSpecialRendererMixin {
	@Shadow
	@Final
	private class_600 model;

	//? if >=1.21.10 {
	/*@Inject(
			method = "submit(Lnet/minecraft/core/component/DataComponentMap;Lnet/minecraft/world/item/ItemDisplayContext;Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/SubmitNodeCollector;IIZI)V",
			at = @At(
					value = "INVOKE",
					target = "Lcom/mojang/blaze3d/vertex/PoseStack;popPose()V"
			)
	)
	private void submitTrim(DataComponentMap argument, ItemDisplayContext displayContext, PoseStack poseStack, SubmitNodeCollector nodeCollector, int packedLight, int packedOverlay, boolean hasFoil, int outlineColor, CallbackInfo ci) {
		TrimicaClientApi.getInstance().getRenderer().submitShieldTrim(model.plate(), argument, poseStack, nodeCollector, packedLight, packedOverlay, hasFoil, outlineColor);
	}
	*///?} else {
	@Inject(
			method = "render(Lnet/minecraft/core/component/DataComponentMap;Lnet/minecraft/world/item/ItemDisplayContext;Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;IIZ)V",
			at = @At(
					value = "INVOKE",
					target = "Lcom/mojang/blaze3d/vertex/PoseStack;popPose()V"
			)
	)
	private void renderTrim(class_9323 dataComponentMap, class_811 itemDisplayContext, class_4587 poseStack, class_4597 multiBufferSource, int packedLight, int packedOverlay, boolean hasFoild, CallbackInfo ci) {
		TrimicaClientApi.getInstance().getRenderer().renderShieldTrim(model.method_23774(), dataComponentMap, itemDisplayContext, poseStack, multiBufferSource, packedLight, packedOverlay, hasFoild);
	}
	//?}
}

==> trimica-1.4.3%2B1.21.10-fabric-sources.jar: com/bawnorton/trimica/client/mixin/render/ShieldSpecialRendererMixin.java <==
package com.bawnorton.trimica.client.mixin.render;

import com.bawnorton.trimica.api.client.TrimicaClientApi;
import dev.kikugie.fletching_table.annotation.MixinEnvironment;
import net.minecraft.class_10509;
import net.minecraft.class_11659;
import net.minecraft.class_4587;
import net.minecraft.class_600;
import net.minecraft.class_811;
import net.minecraft.class_9323;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@MixinEnvironment("client")
@Mixin(class_10509.class)
abstract class ShieldSpecialRendererMixin {
	@Shadow
	@Final
	private class_600 model;

	//? if >=1.21.10 {
	@Inject(
			method = "submit(Lnet/minecraft/core/component/DataComponentMap;Lnet/minecraft/world/item/ItemDisplayContext;Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/SubmitNodeCollector;IIZI)V",
			at = @At(
					value = "INVOKE",
					target = "Lcom/mojang/blaze3d/vertex/PoseStack;popPose()V"
			)
	)
	private void submitTrim(class_9323 argument, class_811 displayContext, class_4587 poseStack, class_11659 nodeCollector, int packedLight, int packedOverlay, boolean hasFoil, int outlineColor, CallbackInfo ci) {
		TrimicaClientApi.getInstance().getRenderer().submitShieldTrim(model.method_23774(), argument, poseStack, nodeCollector, packedLight, packedOverlay, hasFoil, outlineColor);
	}
	//?} else {
	/*@Inject(
			method = "render(Lnet/minecraft/core/component/DataComponentMap;Lnet/minecraft/world/item/ItemDisplayContext;Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;IIZ)V",
			at = @At(
					value = "INVOKE",
					target = "Lcom/mojang/blaze3d/vertex/PoseStack;popPose()V"
			)
	)
	private void renderTrim(DataComponentMap dataComponentMap, ItemDisplayContext itemDisplayContext, PoseStack poseStack, MultiBufferSource multiBufferSource, int packedLight, int packedOverlay, boolean hasFoild, CallbackInfo ci) {
		TrimicaClientApi.getInstance().getRenderer().renderShieldTrim(model.plate(), dataComponentMap, itemDisplayContext, poseStack, multiBufferSource, packedLight, packedOverlay, hasFoild);
	}
	*///?}
}
